@@ -25,6 +25,11 @@ join tercers t on c.TERCER_ID = t.ID
 join tercers_parametres tp on t.id = tp.tercer_id
 """
 
+sync_condicions_pagament = """
+  select c.ID, c.condicio_pagament
+    from condicions_pagament c
+"""
+
 sync_transportistes = """
 select r.EMPRESA_ID, r.ID, t.NOM_LLARG
 FROM REPARTIDORS r
